<?php

namespace Litepci\Sampleset\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Sampleset\Models\Sampleset;

class SamplesetPolicy
{

    /**
     * Determine if the given user can view the sampleset.
     *
     * @param UserPolicy $user
     * @param Sampleset $sampleset
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sampleset $sampleset)
    {
        if ($user->canDo('sampleset.sampleset.view') && $user->isAdmin()) {
            return true;
        }

        return $sampleset->user_id == user_id() && $sampleset->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sampleset.
     *
     * @param UserPolicy $user
     * @param Sampleset $sampleset
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sampleset.sampleset.create');
    }

    /**
     * Determine if the given user can update the given sampleset.
     *
     * @param UserPolicy $user
     * @param Sampleset $sampleset
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sampleset $sampleset)
    {
        if ($user->canDo('sampleset.sampleset.edit') && $user->isAdmin()) {
            return true;
        }

        return $sampleset->user_id == user_id() && $sampleset->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sampleset.
     *
     * @param UserPolicy $user
     * @param Sampleset $sampleset
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sampleset $sampleset)
    {
        return $sampleset->user_id == user_id() && $sampleset->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sampleset.
     *
     * @param UserPolicy $user
     * @param Sampleset $sampleset
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sampleset $sampleset)
    {
        if ($user->canDo('sampleset.sampleset.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sampleset.
     *
     * @param UserPolicy $user
     * @param Sampleset $sampleset
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sampleset $sampleset)
    {
        if ($user->canDo('sampleset.sampleset.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
